@@ -2,7 +2,7 @@
 from __future__ import unicode_literals
 from spacy.util import load_model_from_init_py, get_model_meta
 from pathlib import Path
-from .lemmatizer.lemmatizer import PolishLemmatizer
+from .Lemmatizer.lemmatizer import PolishLemmatizer
 
 __version__ = get_model_meta(Path(__file__).parent)['version']
 
